@@ -7,6 +7,8 @@ use crate::device::DeviceFlow;
 use crate::error::Error;
 use crate::installed::{InstalledFlow, InstalledFlowReturnMethod};
 use crate::refresh::RefreshFlow;
+
+#[cfg(feature = "service_account")]
 use crate::service_account::{ServiceAccountFlow, ServiceAccountFlowOpts, ServiceAccountKey};
 use crate::storage::{self, Storage, TokenStorage};
 use crate::types::{AccessToken, ApplicationSecret, TokenInfo};
@@ -60,7 +62,9 @@ where
     where
         T: AsRef<str>,
     {
-        self.find_token(scopes, /* force_refresh = */ false).await
+        self.find_token_info(scopes, /* force_refresh = */ false)
+            .await
+            .map(|info| info.into())
     }
 
     /// Return a token for the provided scopes, but don't reuse cached tokens. Instead,
@@ -72,15 +76,27 @@ where
     where
         T: AsRef<str>,
     {
-        self.find_token(scopes, /* force_refresh = */ true).await
+        self.find_token_info(scopes, /* force_refresh = */ true)
+            .await
+            .map(|info| info.into())
+    }
+
+    /// Return the current ID token for the provided scopes, if any
+    pub async fn id_token<'a, T>(&'a self, scopes: &'a [T]) -> Result<Option<String>, Error>
+    where
+        T: AsRef<str>,
+    {
+        self.find_token_info(scopes, /* force_refresh = */ false)
+            .await
+            .map(|info| info.id_token)
     }
 
     /// Return a cached token or fetch a new one from the server.
-    async fn find_token<'a, T>(
+    async fn find_token_info<'a, T>(
         &'a self,
         scopes: &'a [T],
         force_refresh: bool,
-    ) -> Result<AccessToken, Error>
+    ) -> Result<TokenInfo, Error>
     where
         T: AsRef<str>,
     {
@@ -116,7 +132,7 @@ where
                     .storage
                     .set(hashed_scopes, token_info.clone())
                     .await?;
-                Ok(token_info.into())
+                Ok(token_info)
             }
             _ => {
                 // no token in the cache or the token returned can't be refreshed.
@@ -129,7 +145,7 @@ where
                     .storage
                     .set(hashed_scopes, token_info.clone())
                     .await?;
-                Ok(token_info.into())
+                Ok(token_info)
             }
         }
     }
@@ -228,7 +244,10 @@ impl DeviceFlowAuthenticator {
 ///         .expect("failed to create authenticator");
 /// # }
 /// ```
+#[cfg(feature = "service_account")]
 pub struct ServiceAccountAuthenticator;
+
+#[cfg(feature = "service_account")]
 impl ServiceAccountAuthenticator {
     /// Use the builder pattern to create an Authenticator that uses a service account.
     #[cfg(any(feature = "hyper-rustls", feature = "hyper-tls"))]
@@ -259,7 +278,7 @@ impl ServiceAccountAuthenticator {
 
 /// Create an authenticator that uses a application default credentials.
 /// ```
-/// # #[cfg(any(feature = "hyper-rustls", feature = "hyper-tls"))]
+/// # #[cfg(all(any(feature = "hyper-rustls", feature = "hyper-tls"), feature = "service_account"))]
 /// # async fn foo() {
 /// #    use yup_oauth2::ApplicationDefaultCredentialsAuthenticator;
 /// #    use yup_oauth2::ApplicationDefaultCredentialsFlowOpts;
@@ -281,6 +300,7 @@ impl ServiceAccountAuthenticator {
 pub struct ApplicationDefaultCredentialsAuthenticator;
 impl ApplicationDefaultCredentialsAuthenticator {
     /// Try to build ServiceAccountFlowOpts from the environment
+    #[cfg(feature = "service_account")]
     pub async fn from_environment() -> Result<ServiceAccountFlowOpts, std::env::VarError> {
         let service_account_key =
             crate::read_service_account_key(std::env::var("GOOGLE_APPLICATION_CREDENTIALS")?)
@@ -295,6 +315,7 @@ impl ApplicationDefaultCredentialsAuthenticator {
 
     /// Use the builder pattern to deduce which model of authenticator should be used:
     /// Service account one or GCE instance metadata kind
+    #[cfg(feature = "service_account")]
     #[cfg(any(feature = "hyper-rustls", feature = "hyper-tls"))]
     #[cfg_attr(
         yup_oauth2_docsrs,
@@ -307,6 +328,7 @@ impl ApplicationDefaultCredentialsAuthenticator {
     }
 
     /// Use the builder pattern to deduce which model of authenticator should be used and allow providing a hyper client
+    #[cfg(feature = "service_account")]
     pub async fn with_client<C>(
         client: C,
         opts: ApplicationDefaultCredentialsFlowOpts,
@@ -332,6 +354,7 @@ where
     C: HyperClientBuilder,
 {
     /// Service account based authenticator signature
+    #[cfg(feature = "service_account")]
     ServiceAccount(AuthenticatorBuilder<C, ServiceAccountFlowOpts>),
     /// GCE Instance Metadata based authenticator signature
     InstanceMetadata(AuthenticatorBuilder<C, ApplicationDefaultCredentialsFlowOpts>),
@@ -535,6 +558,7 @@ impl<C> AuthenticatorBuilder<C, InstalledFlow> {
 ///     .expect("failed to create authenticator");
 /// # }
 /// ```
+#[cfg(feature = "service_account")]
 impl<C> AuthenticatorBuilder<C, ServiceAccountFlowOpts> {
     /// Use the provided subject.
     pub fn subject(self, subject: impl Into<String>) -> Self {
@@ -584,12 +608,14 @@ mod private {
     use crate::device::DeviceFlow;
     use crate::error::Error;
     use crate::installed::InstalledFlow;
+    #[cfg(feature = "service_account")]
     use crate::service_account::ServiceAccountFlow;
     use crate::types::{ApplicationSecret, TokenInfo};
 
     pub enum AuthFlow {
         DeviceFlow(DeviceFlow),
         InstalledFlow(InstalledFlow),
+        #[cfg(feature = "service_account")]
         ServiceAccountFlow(ServiceAccountFlow),
         ApplicationDefaultCredentialsFlow(ApplicationDefaultCredentialsFlow),
     }
@@ -599,6 +625,7 @@ mod private {
             match self {
                 AuthFlow::DeviceFlow(device_flow) => Some(&device_flow.app_secret),
                 AuthFlow::InstalledFlow(installed_flow) => Some(&installed_flow.app_secret),
+                #[cfg(feature = "service_account")]
                 AuthFlow::ServiceAccountFlow(_) => None,
                 AuthFlow::ApplicationDefaultCredentialsFlow(_) => None,
             }
@@ -618,6 +645,7 @@ mod private {
                 AuthFlow::InstalledFlow(installed_flow) => {
                     installed_flow.token(hyper_client, scopes).await
                 }
+                #[cfg(feature = "service_account")]
                 AuthFlow::ServiceAccountFlow(service_account_flow) => {
                     service_account_flow.token(hyper_client, scopes).await
                 }
